CONTENT_ENCODING = "UTF-8"
CONTENT_TYPE_URLENCODED = "application/x-www-form-urlencoded"
ENV_SECURE_DOMAIN = 'SecureDomain'
ENV_JOB_SERVICE_CLIENT_ID = 'JobsvcClientId'
ENV_JOB_SERVICE_CLIENT_SECRET = 'JobsvcClientSecret'
ENV_FIREHOSE_ACCESS_KEY_ID = 'FirehoseAccessKeyId'
ENV_FIREHOSE_SECRET_KEY_ID = 'FirehoseSecretKeyId'
ENV_IS_KINESIS_PUT = 'IsKinesisPut'
ENV_KINESIS_STREAM_NAME = 'KinesisStreamName'
ENV_COMPLIANCE_EMAIL_ADDRESS = 'ComplianceEmailAddress'
ENV_COMPLIANCE_CC_EMAIL_ADDRESS = 'ComplianceCcEmailAddress'
ENV_COMPLIANCE_EMAIL_FROM_DOMAIN = 'ComplianceEmailFromDomain'
ENV_COMPLIANCE_EMAIL_SUBJECT = 'ComplianceEmailSubject'
ENV_SPARKPOST_SNS_TOPIC_ARN = 'SparkpostTopicArn'
ENV_SPARKPOST_S3_BUCKET_NAME = 'SparkpostS3BucketName'
ENV_IS_CALL_SPARKPOST = 'IsCallSparkpost'
HEADER_AUTHORIZATION = "Authorization"
HEADER_CONTENT_TYPE = "Content-Type"
HEADER_ACCEPT = "Accept"
JWT_TOKEN_PATH = "oauth/token"
TOKEN = "token"
USER_TYPE_CUSTOMER = "customer"
USER_TYPE_TECH_PRO = "techpro"
VALIDATIONS_PATH = "oauth/validations"
